@@ -27,12 +27,11 @@ class PristineTar(Command):
 
     def __init__(self, repo):
         self.repo = repo
-        super(PristineTar, self).__init__(self.cmd, cwd=repo.path)
+        super(PristineTar, self).__init__(self.cmd, cwd=repo.path, capture_stderr=True)
 
     def has_commit(self, archive_regexp):
         """
-        Do we have a pristine-tar commit for package I{package} at version
-        {version} with compression type I{comp_type}?
+        Do we have a pristine-tar commit for a package matching I{archive_regexp}.
 
         @param archive_regexp: archive name to look for (regexp wildcards allowed)
         @type archive_regexp: C{str}
@@ -41,8 +40,7 @@ class PristineTar(Command):
 
     def get_commit(self, archive_regexp):
         """
-        Get the pristine-tar commit of package I{package} in version I{version}
-        and compression type I{comp_type}
+        Get the pristine-tar commit of a package matching I{archive_regexp}.
 
         @param archive_regexp: archive name to look for (regexp wildcards allowed)
         @type archive_regexp: C{str}
@@ -65,7 +63,7 @@ class PristineTar(Command):
         @param archive: the name of the orig archive
         @type archive: C{str}
         """
-        self.run_error = 'Couldn\'t checkout "%s"' % os.path.basename(archive)
+        self.run_error = 'Pristine-tar couldn\'t checkout "%s": {stderr}' % os.path.basename(archive)
         self.__call__(['checkout', archive])
 
     def commit(self, archive, upstream):
@@ -78,9 +76,7 @@ class PristineTar(Command):
         @param upstream: the upstream branch to diff against
         @type upstream: C{str}
         """
-        ref = 'refs/heads/%s' % upstream
-
-        self.run_error = ("Couldn't commit to '%s' with upstream '%s'" %
+        self.run_error = ("Couldn't commit to '%s' with upstream '%s': {stderr}" %
                           (self.branch, upstream))
         self.__call__(['commit', archive, upstream])
 
