@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006-2014 Guido Günther <agx@sigxcpu.org>
+# (C) 2006-2015 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -15,9 +15,9 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-"""Build a debian package out of a GIT repository"""
+"""Build a Debian package out of a Git repository"""
 
-import ConfigParser
+from six.moves import configparser
 import errno
 import os, os.path
 import sys
@@ -29,7 +29,7 @@ from gbp.command_wrappers import (Command,
 from gbp.config import (GbpOptionParserDebian, GbpOptionGroup)
 from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
 from gbp.deb.source import DebianSource, DebianSourceError
-from gbp.format import format_msg
+from gbp.format import format_str
 from gbp.git.vfs import GitVfs
 from gbp.deb.upstreamsource import DebianUpstreamSource
 from gbp.errors import GbpError
@@ -293,7 +293,7 @@ def guess_comp_type(repo, comp_type, cp, tarball_dir):
 
     if comp_type != 'auto':
         comp_type = compressor_aliases.get(comp_type, comp_type)
-        if not compressor_opts.has_key(comp_type):
+        if comp_type not in compressor_opts:
             gbp.log.warn("Unknown compression type - guessing.")
             comp_type = 'auto'
 
@@ -372,7 +372,7 @@ def changes_file_suffix(dpkg_args):
 def build_parser(name, prefix=None):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name), prefix=prefix)
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -534,6 +534,7 @@ def main(argv):
                 gbp.log.err("You are not on branch '%s' but on '%s'" % (options.debian_branch, branch))
                 raise GbpError("Use --git-ignore-branch to ignore or --git-debian-branch to set the branch name.")
 
+        head = repo.head
         tree = write_tree(repo, options)
         source = source_vfs(repo, options, tree)
         if not options.tag_only:
@@ -604,12 +605,14 @@ def main(argv):
             gbp.log.info("Tagging %s as %s" % (source.changelog.version, tag))
             if options.retag and repo.has_tag(tag):
                 repo.delete_tag(tag)
-            tag_msg = format_msg(options.debian_tag_msg,
+            tag_msg = format_str(options.debian_tag_msg,
                                  dict(pkg=source.sourcepkg,
                                       version=source.changelog.version))
             repo.create_tag(name=tag,
                             msg=tag_msg,
-                            sign=options.sign_tags, keyid=options.keyid)
+                            sign=options.sign_tags,
+                            commit=head,
+                            keyid=options.keyid)
             if options.posttag:
                 sha = repo.rev_parse("%s^{}" % tag)
                 Hook('Posttag', options.posttag, shell=True,
@@ -619,7 +622,7 @@ def main(argv):
     except CommandExecFailed:
         retval = 1
     except (GbpError, GitRepositoryError) as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         retval = 1
     except DebianSourceError as err:
@@ -633,11 +636,12 @@ def main(argv):
         if options.export_dir and options.purge and not retval:
             RemoveTree(export_dir)()
 
-        if source and not gbp.notifications.notify(source.changelog,
-                                                   not retval,
-                                                   options.notify):
-            gbp.log.err("Failed to send notification")
-            retval = 1
+        if source:
+            summary, msg = gbp.notifications.build_msg(source.changelog,
+                                                       not retval)
+            if not gbp.notifications.notify(summary, msg, options.notify):
+                gbp.log.err("Failed to send notification")
+                retval = 1
 
     return retval
 
