@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2007, 2008, 2009, 2010, 2013 Guido Guenther <agx@sigxcpu.org>
+# (C) 2007, 2008, 2009, 2010, 2013, 2015 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -15,9 +15,11 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-"""Generate Debian changelog entries from GIT commit messages"""
+"""Generate Debian changelog entries from Git commit messages"""
 
-import ConfigParser
+from __future__ import print_function
+
+from six.moves import configparser
 import os.path
 import re
 import sys
@@ -36,18 +38,19 @@ user_customizations = {}
 snapshot_re = re.compile("\s*\*\* SNAPSHOT build @(?P<commit>[a-z0-9]+)\s+\*\*")
 
 
-def guess_version_from_upstream(repo, upstream_tag_format, cp):
+def guess_version_from_upstream(repo, upstream_tag_format, upstream_branch, cp):
     """
     Guess the version based on the latest version on the upstream branch
     """
     try:
         version = repo.debian_version_from_upstream(upstream_tag_format,
+                                                    upstream_branch,
                                                     epoch=cp.epoch)
         gbp.log.debug("Found upstream version %s." % version)
         if compare_versions(version, cp.version) > 0:
             return version
-    except GitRepositoryError:
-        gbp.log.debug("No upstream tag found")
+    except GitRepositoryError as e:
+        gbp.log.debug("No upstream tag found: %s" % e)
     return None
 
 
@@ -137,8 +140,8 @@ def mangle_changelog(changelog, cp, snapshot=''):
         cw = open(tmpfile, 'w')
         cr = open(changelog, 'r')
 
-        print >>cw, ("%(Source)s (%(MangledVersion)s) "
-                     "%(Distribution)s; urgency=%(urgency)s\n" % cp)
+        print("%(Source)s (%(MangledVersion)s) "
+                    "%(Distribution)s; urgency=%(urgency)s\n" % cp, file=cw)
 
         cr.readline() # skip version and empty line
         cr.readline()
@@ -148,10 +151,10 @@ def mangle_changelog(changelog, cp, snapshot=''):
             line = ''
 
         if snapshot:
-            print >>cw, "  ** SNAPSHOT build @%s **\n" % snapshot
+            print("  ** SNAPSHOT build @%s **\n" % snapshot, file=cw)
 
         if line:
-            print >>cw, line.rstrip()
+            print(line.rstrip(), file=cw)
         shutil.copyfileobj(cr, cw)
         cw.close()
         cr.close()
@@ -295,7 +298,7 @@ def build_parser(name):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name),
                                        usage='%prog [options] paths')
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -316,6 +319,7 @@ def build_parser(name):
     parser.add_option_group(custom_group)
 
     parser.add_boolean_config_file_option(option_name = "ignore-branch", dest="ignore_branch")
+    naming_group.add_config_file_option(option_name="upstream-branch", dest="upstream_branch")
     naming_group.add_config_file_option(option_name="debian-branch", dest="debian_branch")
     naming_group.add_config_file_option(option_name="upstream-tag", dest="upstream_tag")
     naming_group.add_config_file_option(option_name="debian-tag", dest="debian_tag")
@@ -472,7 +476,8 @@ def main(argv):
 
         if add_section and not version_change and not source.is_native():
             # Get version from upstream if none provided
-            v = guess_version_from_upstream(repo, options.upstream_tag, cp)
+            v = guess_version_from_upstream(repo, options.upstream_tag,
+                                            options.upstream_branch, cp)
             if v:
                 version_change['version'] = v
 
@@ -540,7 +545,7 @@ def main(argv):
             GitRepositoryError,
             DebianSourceError,
             NoChangeLogError) as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         ret = 1
     return ret
