@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007,2011,2012 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006, 2007, 2011, 2012, 2015 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -14,9 +14,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-"""Import a Debian source package into a GIT repository"""
+"""Import a Debian source package into a Git repository"""
 
-import ConfigParser
+from six.moves import configparser
 import sys
 import re
 import os
@@ -143,7 +143,7 @@ def apply_debian_patch(repo, unpack_dir, src, options, tag):
             raise GbpError
 
         if os.path.exists('debian/rules'):
-            os.chmod('debian/rules', 0755)
+            os.chmod('debian/rules', 0o755)
         os.chdir(repo.path)
 
         parents = check_parents(repo,
@@ -165,7 +165,7 @@ def apply_debian_patch(repo, unpack_dir, src, options, tag):
                             sign=options.sign_tags,
                             keyid=options.keyid)
     except (gbpc.CommandExecFailed, GitRepositoryError) as err:
-        msg = err.__str__() if len(err.__str__()) else ''
+        msg = str(err) or 'Unknown error, please report a bug'
         gbp.log.err("Failed to import Debian package: %s" % msg)
         raise GbpError
     finally:
@@ -208,7 +208,7 @@ def build_parser(name):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name), prefix='',
                                        usage='%prog [options] /path/to/package.dsc')
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -280,7 +280,6 @@ def main(argv):
     needs_repo = False
     ret = 0
     skipped = False
-    parents = None
 
     options, args = parse_args(argv)
     if not options:
@@ -403,7 +402,7 @@ def main(argv):
         gbp.log.err("Git command failed: %s" % msg)
         ret = 1
     except GbpError as err:
-        if len(err.__str__()):
+        if str(err):
             gbp.log.err(err)
         ret = 1
     except SkipImport:
@@ -412,7 +411,7 @@ def main(argv):
         os.chdir(dirs['top'])
 
     for d in [ 'tmp', 'download' ]:
-        if dirs.has_key(d):
+        if d in dirs:
             gbpc.RemoveTree(dirs[d])()
 
     if not ret and not skipped:
