@@ -3,14 +3,12 @@
 """Test L{gbp.scripts.dch} main"""
 
 from . import context
-
-import unittest
-
-from tests.testutils import (DebianGitTestRepo, OsReleaseFile,
-                             get_dch_default_urgency)
+from .testutils import (DebianGitTestRepo, OsReleaseFile,
+                        get_dch_default_urgency, capture_stderr)
 
 from gbp.scripts import dch
 
+import unittest
 import os
 import re
 
@@ -59,6 +57,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.repo.create_tag("upstream/0.9", msg="upstream version 0.9")
         self.add_file("bar", "foo")
         self.repo.create_tag("upstream/1.0", msg="upstream version 1.0")
+        self.repo.create_branch("upstream")
         self.repo.create_branch("debian")
         self.repo.set_branch("debian")
         self.upstream_tag = "upstream/%(version)s"
@@ -68,7 +67,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.add_file("debian/changelog", cl_debian)
         self.add_file("debian/control", """Source: test-package\nSection: test\n""")
         self.options = ["--upstream-tag=%s" % self.upstream_tag, "--debian-branch=debian",
-                        "--id-length=0", "--spawn-editor=/bin/true"]
+                        "--upstream-branch=upstream", "--id-length=0", "--spawn-editor=/bin/true"]
         self.repo.create_tag(deb_tag, msg=deb_tag_msg, commit="HEAD~1")
 
 
@@ -87,14 +86,14 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version(self):
-        """Test dch.py like git-dch script does: new upstream version"""
+        """Test dch.py like gbp dch script does: new upstream version"""
         lines = self.run_dch()
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=%s\n" % default_urgency, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
     def test_dch_main_new_upstream_version_with_release(self):
-        """Test dch.py like git-dch script does: new upstream version - release"""
+        """Test dch.py like gbp dch script does: new upstream version - release"""
         options = ["--release"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) %s; urgency=%s\n" % (os_codename, default_urgency), lines[0])
@@ -102,7 +101,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_auto(self):
-        """Test dch.py like git-dch script does: new upstream version - guess last commit"""
+        """Test dch.py like gbp dch script does: new upstream version - guess last commit"""
         options = ["--auto"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=%s\n" % default_urgency, lines[0])
@@ -110,7 +109,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_snapshot(self):
-        """Test dch.py like git-dch script does: new upstream version - snapshot mode"""
+        """Test dch.py like gbp dch script does: new upstream version - snapshot mode"""
         options = ["--snapshot"]
         lines = self.run_dch(options)
         header = re.search(snap_header_1, lines[0])
@@ -121,7 +120,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_2_snapshots_auto(self):
-        """Test dch.py like git-dch script does: new upstream version - two snapshots - auto"""
+        """Test dch.py like gbp dch script does: new upstream version - two snapshots - auto"""
         options = ["--snapshot"]
         lines = self.run_dch(options)
         header1 = re.search(snap_header_1, lines[0])
@@ -144,7 +143,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_2_snapshots_commit_auto(self):
-        """Test dch.py like git-dch script does: new upstream version - two committed snapshots - auto"""
+        """Test dch.py like gbp dch script does: new upstream version - two committed snapshots - auto"""
         options = ["--commit"]
         options.append("--commit-msg=TEST-COMMITTED-SNAPSHOT")
         options.append("--snapshot")
@@ -171,7 +170,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_auto_release(self):
-        """Test dch.py like git-dch script does: new upstream version - auto - release"""
+        """Test dch.py like gbp dch script does: new upstream version - auto - release"""
         options = ["--auto", "--release"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) %s; urgency=%s\n" % (os_codename, default_urgency), lines[0])
@@ -179,7 +178,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_auto_snapshot(self):
-        """Test dch.py like git-dch script does: new upstream version - auto - snapshot mode"""
+        """Test dch.py like gbp dch script does: new upstream version - auto - snapshot mode"""
         options = [ "--auto", "--snapshot" ]
         options.append("--snapshot")
         lines = self.run_dch(options)
@@ -191,13 +190,15 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_snapshot_release(self):
-        """Test dch.py like git-dch script does: new upstream version - snapshot - release"""
+        """Test dch.py like gbp dch script does: new upstream version - snapshot - release"""
         options = ["--snapshot", "--release"]
-        self.assertRaises(SystemExit, self.run_dch, options)
+        with capture_stderr() as c:
+            self.assertRaises(SystemExit, self.run_dch, options)
+        self.assertTrue("'--snapshot' and '--release' are incompatible options" in c.output())
 
 
     def test_dch_main_new_upstream_version_with_distribution(self):
-        """Test dch.py like git-dch script does: new upstream version - set distribution"""
+        """Test dch.py like gbp dch script does: new upstream version - set distribution"""
         options = ["--distribution=testing", "--force-distribution"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) testing; urgency=%s\n" % default_urgency, lines[0])
@@ -205,7 +206,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_release_distribution(self):
-        """Test dch.py like git-dch script does: new upstream version - release - set distribution"""
+        """Test dch.py like gbp dch script does: new upstream version - release - set distribution"""
         options = ["--release", "--distribution=testing", "--force-distribution"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) testing; urgency=%s\n" % default_urgency, lines[0])
@@ -213,7 +214,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_snapshot_distribution(self):
-        """Test dch.py like git-dch script does: new upstream version - snapshot mode - do not set distribution"""
+        """Test dch.py like gbp dch script does: new upstream version - snapshot mode - do not set distribution"""
         options = ["--snapshot", "--distribution=testing"]
         lines = self.run_dch(options)
         header = re.search(snap_header_1, lines[0])
@@ -224,7 +225,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_2_snapshots_auto_distribution(self):
-        """Test dch.py like git-dch script does: new upstream version - two snapshots - do not set distribution"""
+        """Test dch.py like gbp dch script does: new upstream version - two snapshots - do not set distribution"""
         options = ["--snapshot", "--distribution=testing"]
         lines = self.run_dch(options)
         header1 = re.search(snap_header_1, lines[0])
@@ -250,7 +251,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_2_snapshots_commit_auto_distribution(self):
-        """Test dch.py like git-dch script does: new upstream version - two committed snapshots - do not set distribution"""
+        """Test dch.py like gbp dch script does: new upstream version - two committed snapshots - do not set distribution"""
         options = ["--commit"]
         options.append("--commit-msg=TEST-COMMITTED-SNAPSHOT")
         options.append("--snapshot")
@@ -278,7 +279,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_urgency(self):
-        """Test dch.py like git-dch script does: new upstream version - set urgency"""
+        """Test dch.py like gbp dch script does: new upstream version - set urgency"""
         options = ["--urgency=emergency"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=emergency\n", lines[0])
@@ -286,7 +287,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_release_urgency(self):
-        """Test dch.py like git-dch script does: new upstream version - release - set urgency"""
+        """Test dch.py like gbp dch script does: new upstream version - release - set urgency"""
         options = ["--release", "--urgency=emergency"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (1.0-1) %s; urgency=emergency\n" % os_codename, lines[0])
@@ -294,7 +295,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_new_upstream_version_with_snapshot_urgency(self):
-        """Test dch.py like git-dch script does: new upstream version - snapshot mode - set urgency"""
+        """Test dch.py like gbp dch script does: new upstream version - snapshot mode - set urgency"""
         options = ["--snapshot",  "--urgency=emergency"]
         lines = self.run_dch(options)
         header = re.search(snap_header_1, lines[0])
@@ -305,7 +306,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version(self):
-        """Test dch.py like git-dch script does: increment debian version"""
+        """Test dch.py like gbp dch script does: increment debian version"""
         self.repo.delete_tag("debian/0.9-1")
         self.repo.create_tag("debian/0.9-1", msg="Pre stable release version 0.9-1", commit="HEAD~2")
         self.repo.delete_tag("upstream/1.0")
@@ -315,7 +316,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version_with_release(self):
-        """Test dch.py like git-dch script does: increment debian version - release"""
+        """Test dch.py like gbp dch script does: increment debian version - release"""
         self.repo.delete_tag("upstream/1.0")
         options = ["--release"]
         lines = self.run_dch(options)
@@ -324,7 +325,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version_with_auto(self):
-        """Test dch.py like git-dch script does: increment debian version - guess last commit"""
+        """Test dch.py like gbp dch script does: increment debian version - guess last commit"""
         self.repo.delete_tag("upstream/1.0")
         options = ["--auto"]
         lines = self.run_dch(options)
@@ -333,7 +334,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version_with_snapshot(self):
-        """Test dch.py like git-dch script does: increment debian version - snapshot mode"""
+        """Test dch.py like gbp dch script does: increment debian version - snapshot mode"""
         self.repo.delete_tag("upstream/1.0")
         options = ["--snapshot"]
         lines = self.run_dch(options)
@@ -345,7 +346,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version_with_auto_release(self):
-        """Test dch.py like git-dch script does: increment debian version - auto - release"""
+        """Test dch.py like gbp dch script does: increment debian version - auto - release"""
         self.repo.delete_tag("upstream/1.0")
         options = ["--auto",  "--release"]
         lines = self.run_dch(options)
@@ -354,7 +355,7 @@ class TestScriptDch(DebianGitTestRepo):
 
 
     def test_dch_main_increment_debian_version_with_auto_snapshot(self):
-        """Test dch.py like git-dch script does: increment debian version - auto - snapshot mode"""
+        """Test dch.py like gbp dch script does: increment debian version - auto - snapshot mode"""
         self.repo.delete_tag("upstream/1.0")
         options = ["--auto",  "--snapshot"]
         lines = self.run_dch(options)
