@@ -1,5 +1,5 @@
 # vim: set fileencoding=utf-8 :
-# (C) 2012 Guido Günther <agx@sigxcpu.org>
+# (C) 2012,2015 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -16,15 +16,15 @@
 """Test L{gbp.pq}"""
 
 from . import context
+from . import testutils
 
 import os
 import logging
 import unittest
 
-from gbp.scripts.pq import generate_patches, switch_pq, export_patches
+from gbp.scripts.pq import generate_patches, export_patches
 import gbp.scripts.common.pq as pq
 import gbp.patch_series
-import tests.testutils as testutils
 
 class TestApplyAndCommit(testutils.DebianGitTestRepo):
     """Test L{gbp.pq}'s apply_and_commit"""
@@ -47,7 +47,7 @@ class TestApplyAndCommit(testutils.DebianGitTestRepo):
 
         pq.apply_and_commit_patch(self.repo, patch, None, topic='foobar')
         info = self.repo.get_commit_info('HEAD')
-        self.assertIn('Gbp-Pq-Topic: foobar', info['body'])
+        self.assertIn('Gbp-Pq: Topic foobar', info['body'])
 
     @unittest.skipIf(not os.path.exists('/usr/bin/dpkg'), 'Dpkg not found')
     def test_debian_missing_author(self):
@@ -111,7 +111,7 @@ class TestWritePatch(testutils.DebianGitTestRepo):
 
         # Add test file with topic:
         msg = ("added foo\n\n"
-               "Gbp-Pq-Topic: gbptest")
+               "Gbp-Pq: Topic gbptest")
         self.add_file('foo', 'foo', msg)
 
         # Write it out as patch and check it's existence
@@ -120,8 +120,10 @@ class TestWritePatch(testutils.DebianGitTestRepo):
                                      opts)[0]
         expected = os.path.join(str(d), 'gbptest', 'added-foo.patch')
 
+        self.assertEqual(os.path.basename(patchfile),
+                                          'added-foo.patch')
         self.assertTrue(os.path.exists(expected))
-        logging.debug(file(expected).read())
+        logging.debug(open(expected).read())
 
         # Reapply the patch to a new branch
         self.repo.create_branch('testapply', 'HEAD^')
@@ -145,12 +147,37 @@ class TestExport(testutils.DebianGitTestRepo):
         """Test if we drop the patch-queue branch with --drop"""
         repo = self.repo
         start = repo.get_branch()
-        pq = os.path.join('patch-queue', start)
-        switch_pq(repo, start)
-        self.assertEqual(repo.get_branch(), pq)
-        export_patches(repo, pq, TestExport.Options)
+        pq_branch = os.path.join('patch-queue', start)
+        pq.switch_pq(repo, start)
+        self.assertEqual(repo.get_branch(), pq_branch)
+        export_patches(repo, pq_branch, TestExport.Options)
         self.assertEqual(repo.get_branch(), start)
-        self.assertFalse(repo.has_branch(pq))
+        self.assertFalse(repo.has_branch(pq_branch))
+
+
+class TestParseGbpCommand(unittest.TestCase):
+    def test_empty_body(self):
+        """Test command filtering with an empty body"""
+        info = { 'body': '' }
+        (cmds, body) = pq.parse_gbp_commands(info, ['tag'], ['cmd1'], ['cmd2'])
+        self.assertEquals(cmds, {})
+        self.assertEquals(body, '')
+
+    def test_noarg_cmd(self):
+        orig_body = '\n'.join(["Foo",
+                          "tag: cmd1"])
+        info = { 'body': orig_body }
+        (cmds, body) = pq.parse_gbp_commands(info, 'tag', ['cmd'], ['argcmd'])
+        self.assertEquals(cmds, {'cmd': None})
+        self.assertEquals(body, orig_body)
+
+    def test_filter_cmd(self):
+        orig_body = '\n'.join(["Foo",
+                               "tag: cmd1"])
+        info = { 'body': orig_body }
+        (cmds, body) = pq.parse_gbp_commands(info, 'tag', ['cmd'], ['argcmd'], ['cmd'])
+        self.assertEquals(cmds, {'cmd': None})
+        self.assertEquals(body, 'Foo')
 
 
 def _patch_path(name):
